@@ -1,5 +1,5 @@
 /* tls.c - Handle tls/ssl using SSLeay or OpenSSL. */
-/* $OpenLDAP: pkg/ldap/libraries/libldap/tls.c,v 1.118.2.7 2005/10/10 17:35:26 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/libraries/libldap/tls.c,v 1.118.2.8 2005/10/12 18:33:06 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2005 The OpenLDAP Foundation.
@@ -202,8 +202,11 @@ ldap_pvt_tls_init_def_ctx( void )
 #ifdef LDAP_R_COMPILE
 	ldap_pvt_thread_mutex_lock( &tls_def_ctx_mutex );
 #endif
-	if (( !cacertfile && !cacertdir ) || !certfile || !keyfile )
+
+	if ( !certfile && !keyfile && !cacertfile && !cacertdir ) {
+		/* minimum configuration not provided */
 		return LDAP_NOT_SUPPORTED;
+	}
 
 #ifdef HAVE_EBCDIC
 	/* This ASCII/EBCDIC handling is a real pain! */
