@@ -1,4 +1,19 @@
-/* $OpenLDAP: pkg/ldap/libraries/liblutil/hash.c,v 1.2 2000/10/17 22:29:21 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/libraries/liblutil/hash.c,v 1.6.2.1 2005/01/20 18:03:52 kurt Exp $ */
+/* This work is part of OpenLDAP Software <http://www.openldap.org/>.
+ *
+ * Copyright 2000-2005 The OpenLDAP Foundation.
+ * Portions Copyright 2000-2003 Kurt D. Zeilenga.
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted only as authorized by the OpenLDAP
+ * Public License.
+ *
+ * A copy of this license is available in the file LICENSE in the
+ * top-level directory of the distribution or, alternatively, at
+ * <http://www.OpenLDAP.org/license.html>.
+ */
+
 /* This implements the Fowler / Noll / Vo (FNV-1) hash algorithm.
  * A summary of the algorithm can be found at:
  *   http://www.isthe.com/chongo/tech/comp/fnv/index.html
@@ -29,8 +44,7 @@ void
 lutil_HASHUpdate(
     struct lutil_HASHContext	*ctx,
     const unsigned char		*buf,
-    ber_len_t		len
-)
+    ber_len_t		len )
 {
 	const unsigned char *p, *e;
 	ber_uint_t h;
