@@ -1,7 +1,16 @@
-/* $OpenLDAP: pkg/ldap/libraries/liblutil/ptest.c,v 1.5.2.2 2002/01/04 20:38:25 kurt Exp $ */
-/*
- * Copyright 1998-2002 The OpenLDAP Foundation, All Rights Reserved.
- * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
+/* $OpenLDAP: pkg/ldap/libraries/liblutil/ptest.c,v 1.10.2.1 2005/01/20 18:03:52 kurt Exp $ */
+/* This work is part of OpenLDAP Software <http://www.openldap.org/>.
+ *
+ * Copyright 1998-2005 The OpenLDAP Foundation.
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted only as authorized by the OpenLDAP
+ * Public License.
+ *
+ * A copy of this license is available in the file LICENSE in the
+ * top-level directory of the distribution or, alternatively, at
+ * <http://www.OpenLDAP.org/license.html>.
  */
 
 #include "portable.h"
@@ -20,13 +29,11 @@
 
 #include "lutil.h"
 
-// #define SLAP_AUTHPASSWD 1
-
 /*
  * Password Test Program
  */
 
-char *hash[] = {
+static char *hash[] = {
 #ifdef SLAP_AUTHPASSWD
 	"SHA1", "MD5",
 #else
@@ -102,4 +109,4 @@ main( int argc, char *argv[] )
 	}
 
 	return EXIT_SUCCESS;
-}
\ No newline at end of file
+}
