@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/libraries/librewrite/subst.c,v 1.19.2.1 2005/01/20 18:03:53 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/libraries/librewrite/subst.c,v 1.19.2.2 2005/08/09 21:03:56 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2000-2005 The OpenLDAP Foundation.
@@ -453,8 +453,8 @@ rewrite_subst_destroy(
 	int			n;
 	struct rewrite_subst	*subst;
 
-	assert( psubst );
-	assert( *psubst );
+	assert( psubst != NULL );
+	assert( *psubst != NULL );
 
 	subst = *psubst;
 
