@@ -1,5 +1,5 @@
 /* index.c - routines for dealing with attribute indexes */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-bdb/index.c,v 1.46.2.6 2005/05/18 16:29:22 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-bdb/index.c,v 1.46.2.7 2005/08/09 21:04:01 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2000-2005 The OpenLDAP Foundation.
@@ -170,7 +170,7 @@ static int indexer(
 	DB *db;
 	struct berval *keys;
 
-	assert( mask );
+	assert( mask != 0 );
 
 	rc = bdb_db_cache( op->o_bd, atname->bv_val, &db );
 	
@@ -389,7 +389,7 @@ bdb_index_entry(
 #ifdef LDAP_COMP_MATCH
 	ComponentReference *cr_list = NULL;
 	ComponentReference *cr = NULL, *dupped_cr = NULL;
-	void* decoded_comp, *extracted_comp;
+	void* decoded_comp;
 	ComponentSyntaxInfo* csi_attr;
 	Syntax* syn;
 	AttributeType* at;
