@@ -1,5 +1,5 @@
 /* operational.c - bdb backend operational attributes function */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-bdb/operational.c,v 1.24.2.1 2005/01/20 18:03:58 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-bdb/operational.c,v 1.24.2.2 2005/08/09 21:04:01 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2000-2005 The OpenLDAP Foundation.
@@ -36,7 +36,7 @@ bdb_hasSubordinates(
 {
 	int		rc;
 	
-	assert( e );
+	assert( e != NULL );
 
 	/* NOTE: this should never happen, but it actually happens
 	 * when using back-relay; until we find a better way to
@@ -89,7 +89,7 @@ bdb_operational(
 {
 	Attribute	**ap;
 
-	assert( rs->sr_entry );
+	assert( rs->sr_entry != NULL );
 
 	for ( ap = &rs->sr_operational_attrs; *ap; ap = &(*ap)->a_next )
 		/* just count */ ;
@@ -102,7 +102,7 @@ bdb_operational(
 		rc = bdb_hasSubordinates( op, rs->sr_entry, &hasSubordinates );
 		if ( rc == LDAP_SUCCESS ) {
 			*ap = slap_operational_hasSubordinate( hasSubordinates == LDAP_COMPARE_TRUE );
-			assert( *ap );
+			assert( *ap != NULL );
 
 			ap = &(*ap)->a_next;
 		}
