@@ -1,5 +1,5 @@
 /* config.c - ldap backend configuration file routine */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-ldap/config.c,v 1.73.2.9 2005/08/09 21:04:02 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-ldap/config.c,v 1.73.2.10 2005/08/17 16:15:36 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2003-2005 The OpenLDAP Foundation.
@@ -908,8 +908,22 @@ ldap_back_cf_gen( ConfigArgs *c )
 
 	case LDAP_BACK_CFG_IDASSERT_AUTHZFROM: {
 		struct berval	bv;
+#ifdef SLAP_AUTHZ_SYNTAX
+		struct berval	in;
+		int		rc;
 
+		ber_str2bv( c->argv[ 1 ], 0, 0, &in );
+		rc = authzNormalize( 0, NULL, NULL, &in, &bv, NULL );
+		if ( rc != LDAP_SUCCESS ) {
+			fprintf( stderr, "%s: %d: "
+				"\"idassert-authzFrom <authz>\": "
+				"invalid syntax.\n",
+				c->fname, c->lineno );
+			return 1;
+		}
+#else /* !SLAP_AUTHZ_SYNTAX */
 		ber_str2bv( c->argv[ 1 ], 0, 1, &bv );
+#endif /* !SLAP_AUTHZ_SYNTAX */
 		ber_bvarray_add( &li->idassert_authz, &bv );
 		} break;
 
@@ -1562,6 +1576,9 @@ ldap_back_exop_whoami(
 		return rs->sr_err = LDAP_PROTOCOL_ERROR;
 	}
 
+	Statslog( LDAP_DEBUG_STATS, "%s WHOAMI\n",
+	    op->o_log_prefix, 0, 0, 0, 0 );
+
 	rs->sr_err = backend_check_restrictions( op, rs, 
 			(struct berval *)&slap_EXOP_WHOAMI );
 	if( rs->sr_err != LDAP_SUCCESS ) return rs->sr_err;
