@@ -1,5 +1,5 @@
 /* back-ldbm.h - ldap ldbm back-end header file */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-ldbm/back-ldbm.h,v 1.64.2.2 2005/04/29 21:29:07 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-ldbm/back-ldbm.h,v 1.64.2.3 2005/09/28 00:30:33 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2005 The OpenLDAP Foundation.
@@ -18,6 +18,7 @@
 #define _BACK_LDBM_H_
 
 #include "ldbm.h"
+#include "alock.h"
 
 LDAP_BEGIN_DECL
 
@@ -152,6 +153,7 @@ struct ldbminfo {
 	int			li_dbsyncwaitn;
 	int			li_dbsyncwaitinterval;
 	int			li_dbsyncwaitcount;
+	alock_info_t	li_alock_info;
 };
 
 LDAP_END_DECL
