@@ -1,5 +1,5 @@
 /* ldif.c - the ldif backend */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-ldif/ldif.c,v 1.1.2.8 2005/08/09 21:04:03 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-ldif/ldif.c,v 1.1.2.10 2005/08/29 18:26:10 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2005 The OpenLDAP Foundation.
@@ -330,7 +330,7 @@ static int r_enum_tree(enumCookie *ck, struct berval *path,
 							? LDAP_SCOPE_BASE : LDAP_SCOPE_SUBTREE );
 
 				ck->rs->sr_entry = e;
-				rc = send_search_reference( ck->op, ck->rs ) < 0;
+				rc = send_search_reference( ck->op, ck->rs );
 				ber_bvarray_free( ck->rs->sr_ref );
 				ber_bvarray_free( erefs );
 				ck->rs->sr_ref = NULL;
@@ -341,12 +341,12 @@ static int r_enum_tree(enumCookie *ck, struct berval *path,
 				ck->rs->sr_entry = e;
 				ck->rs->sr_attrs = ck->op->ors_attrs;
 				ck->rs->sr_flags = REP_ENTRY_MODIFIABLE;
-				rc = send_search_entry(ck->op, ck->rs) < 0;
+				rc = send_search_entry(ck->op, ck->rs);
 				ck->rs->sr_entry = NULL;
 			}
 			fd = 1;
 			if ( rc )
-				goto leave;
+				goto done;
 		} else {
 		/* Queueing up for tool mode */
 			if(ck->entries == NULL) {
@@ -382,7 +382,7 @@ static int r_enum_tree(enumCookie *ck, struct berval *path,
 					"=> ldif_enum_tree: failed to opendir %s (%d)\n",
 					path->bv_val, errno, 0 );
 			}
-			goto leave;
+			goto done;
 		}
 	
 		while(1) {
@@ -453,7 +453,7 @@ static int r_enum_tree(enumCookie *ck, struct berval *path,
 			free(ptr);
 		}
 	}
-leave:
+done:
 	if ( fd ) entry_free( e );
 	return rc;
 }
