@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-meta/conn.c,v 1.31.2.10 2005/10/05 17:42:20 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-meta/conn.c,v 1.31.2.11 2005/10/10 17:35:27 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1999-2005 The OpenLDAP Foundation.
@@ -503,7 +503,7 @@ meta_back_get_candidate(
 	struct berval	*ndn )
 {
 	metainfo_t	*mi = ( metainfo_t * )op->o_bd->be_private;
-	int		candidate;
+	long		candidate;
 
 	/*
 	 * tries to get a unique candidate
