@@ -1,5 +1,5 @@
 /* database.c - deals with database subsystem */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-monitor/database.c,v 1.61.2.5 2005/06/03 19:54:16 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-monitor/database.c,v 1.61.2.6 2005/08/09 21:04:04 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2001-2005 The OpenLDAP Foundation.
@@ -54,6 +54,12 @@ static int monitor_back_add_plugin( monitor_info_t *mi, Backend *be, Entry *e );
 #define PATH_MAX	4095
 #endif /* ! PATH_MAX */
 
+static int
+monitor_subsys_database_modify(
+	Operation	*op,
+	SlapReply	*rs,
+	Entry		*e );
+
 static struct restricted_ops_t {
 	struct berval	op;
 	unsigned int	tag;
@@ -129,6 +135,8 @@ monitor_subsys_database_init(
 
 	assert( be != NULL );
 
+	ms->mss_modify = monitor_subsys_database_modify;
+
 	mi = ( monitor_info_t * )be->be_private;
 
 	ms_backend = monitor_back_get_subsys( SLAPD_MONITOR_BACKEND_NAME );
@@ -280,7 +288,7 @@ monitor_subsys_database_init(
 						break;
 					}
 				}
-				assert( on2 );
+				assert( on2 != NULL );
 
 				snprintf( buf, sizeof( buf ), 
 					"cn=Overlay %d,%s", 
@@ -429,7 +437,7 @@ monitor_subsys_database_init(
 						break;
 					}
 				}
-				assert( on2 );
+				assert( on2 != NULL );
 
 				snprintf( buf, sizeof( buf ),
 						"dn: cn=Overlay %d,cn=Database %d,%s\n"
@@ -545,12 +553,11 @@ value_mask( BerVarray v, slap_mask_t cur, slap_mask_t *delta )
 	return LDAP_SUCCESS;
 }
 
-int
+static int
 monitor_subsys_database_modify(
 	Operation	*op,
 	SlapReply	*rs,
-	Entry		*e
-)
+	Entry		*e )
 {
 	monitor_info_t	*mi = (monitor_info_t *)op->o_bd->be_private;
 	int		rc = LDAP_OTHER;
