@@ -1,5 +1,5 @@
 /* init.c - initialize monitor backend */
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-monitor/init.c,v 1.89.2.9 2005/09/28 00:30:34 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-monitor/init.c,v 1.89.2.10 2005/10/12 21:33:52 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2001-2005 The OpenLDAP Foundation.
@@ -642,7 +642,7 @@ monitor_filter2ndn(
 	struct berval	*ndn )
 {
 	Connection	conn = { 0 };
-	char		opbuf[OPERATION_BUFFER_SIZE];
+	OperationBuffer	opbuf;
 	Operation	*op;
 	SlapReply	rs = { 0 };
 	slap_callback	cb = { NULL, monitor_filter2ndn_cb, NULL, NULL };
@@ -654,7 +654,7 @@ monitor_filter2ndn(
 		return -1;
 	}
 
-	op = (Operation *)opbuf;
+	op = (Operation *) &opbuf;
 	connection_fake_init( &conn, op, &conn );
 
 	op->o_tag = LDAP_REQ_SEARCH;
