@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/servers/slapd/back-sql/config.c,v 1.17.2.4 2005/06/09 16:31:12 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/back-sql/config.c,v 1.17.2.5 2005/08/09 21:04:05 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1999-2005 The OpenLDAP Foundation.
@@ -53,7 +53,7 @@ backsql_db_config(
 	backsql_info 	*bi = (backsql_info *)be->be_private;
 
 	Debug( LDAP_DEBUG_TRACE, "==>backsql_db_config()\n", 0, 0, 0 );
-	assert( bi );
+	assert( bi != NULL );
   
 	if ( !strcasecmp( argv[ 0 ], "dbhost" ) ) {
 		if ( argc < 2 ) {
@@ -649,7 +649,7 @@ read_baseObject(
 	int		rc = 0, lineno = 0, lmax = 0;
 	char		*buf = NULL;
 
-	assert( fname );
+	assert( fname != NULL );
 
 	fp = ldif_open( fname, "r" );
 	if ( fp == NULL ) {
@@ -788,7 +788,7 @@ create_baseObject(
 		struct berval			bv = BER_BVNULL;
 		const char			*text = NULL;
 
-		assert( ava );
+		assert( ava != NULL );
 
 		rc = slap_bv2ad( &ava->la_attr, &ad, &text );
 		if ( rc != LDAP_SUCCESS ) {
