@@ -1,5 +1,5 @@
 /* config.c - configuration file handling routines */
-/* $OpenLDAP: pkg/ldap/servers/slapd/config.c,v 1.341.2.12 2005/09/28 00:30:30 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/config.c,v 1.341.2.13 2005/10/11 17:42:18 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2005 The OpenLDAP Foundation.
@@ -191,7 +191,7 @@ int config_check_vals(ConfigTable *Conf, ConfigArgs *c, int check_only ) {
 		int j;
 		iarg = 0; larg = 0; barg = 0;
 		switch(arg_type & ARGS_NUMERIC) {
-			case ARG_INT:		iarg = atoi(c->argv[1]);		break;
+			case ARG_INT:		iarg = strtol(c->argv[1], NULL, 0); break;
 			case ARG_LONG:		larg = strtol(c->argv[1], NULL, 0);	break;
 			case ARG_BER_LEN_T:	barg = (ber_len_t)atol(c->argv[1]);	break;
 			case ARG_ON_OFF:
