@@ -38,10 +38,6 @@
 
 #include "ldap_rq.h"
 
-#ifdef LDAP_SLAPI
-#include "slapi/slapi.h"
-#endif
-
 static BackendInfo	slap_frontendInfo;
 static BackendDB	slap_frontendDB;
 BackendDB	*frontendDB;
@@ -82,6 +78,8 @@ frontend_init( void )
 	/* info */
 	frontendDB->bd_info = &slap_frontendInfo;
 
+	SLAP_BFLAGS(frontendDB) |= SLAP_BFLAG_FRONTEND;
+
 	/* name */
 	frontendDB->bd_info->bi_type = "frontend";
 
@@ -116,6 +114,16 @@ frontend_init( void )
 	frontendDB->bd_info->bi_op_modrdn = fe_op_modrdn;
 	frontendDB->bd_info->bi_op_search = fe_op_search;
 	frontendDB->bd_info->bi_extended = fe_extended;
+	frontendDB->bd_info->bi_operational = fe_aux_operational;
+#if 0
+	frontendDB->bd_info->bi_entry_get_rw = fe_entry_get_rw;
+	frontendDB->bd_info->bi_entry_release_rw = fe_entry_release_rw;
+#endif
+#ifdef SLAP_OVERLAY_ACCESS
+	frontendDB->bd_info->bi_access_allowed = fe_access_allowed;
+	frontendDB->bd_info->bi_acl_group = fe_acl_group;
+	frontendDB->bd_info->bi_acl_attribute = fe_acl_attribute;
+#endif /* SLAP_OVERLAY_ACCESS */
 
 #if 0
 	/* FIXME: is this too early? */
