@@ -27,7 +27,7 @@ slap_operational_subschemaSubentry( Backend *be )
 	Attribute	*a;
 
 	/* The backend wants to take care of it */
-	if ( be && be!= frontendDB && be->be_schemadn.bv_val ) return NULL;
+	if ( be && !SLAP_FRONTEND(be) && be->be_schemadn.bv_val ) return NULL;
 
 	a = ch_malloc( sizeof( Attribute ) );
 	a->a_desc = slap_schema.si_ad_subschemaSubentry;
@@ -53,7 +53,7 @@ slap_operational_entryDN( Entry *e )
 {
 	Attribute	*a;
 
-	assert( e );
+	assert( e != NULL );
 	assert( !BER_BVISNULL( &e->e_name ) );
 	assert( !BER_BVISNULL( &e->e_nname ) );
 
