@@ -1,5 +1,5 @@
 /* overlays.c - Static overlay framework */
-/* $OpenLDAP: pkg/ldap/servers/slapd/overlays/overlays.c,v 1.12.2.5 2005/08/09 21:04:07 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/overlays/overlays.c,v 1.12.2.6 2005/08/25 05:01:19 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2003-2005 The OpenLDAP Foundation.
@@ -65,6 +65,9 @@ extern int translucent_init();
 #if SLAPD_OVER_UNIQUE == SLAPD_MOD_STATIC
 extern int unique_init();
 #endif
+#if SLAPD_OVER_VALSORT == SLAPD_MOD_STATIC
+extern int valsort_init();
+#endif
 
 static struct {
 	char *name;
@@ -111,6 +114,9 @@ static struct {
 #endif
 #if SLAPD_OVER_UNIQUE == SLAPD_MOD_STATIC
 	{ "Attribute Uniqueness", unique_init },
+#endif
+#if SLAPD_OVER_VALSORT == SLAPD_MOD_STATIC
+	{ "Value Sorting", valsort_init },
 #endif
 	{ NULL, NULL }
 };
