@@ -1,5 +1,5 @@
 /* unique.c - attribute uniqueness module */
-/* $OpenLDAP: pkg/ldap/servers/slapd/overlays/unique.c,v 1.8.2.6 2005/10/05 17:42:20 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/overlays/unique.c,v 1.8.2.7 2005/10/11 17:42:19 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2004-2005 The OpenLDAP Foundation.
@@ -490,7 +490,7 @@ static int unique_modrdn(
 		op->o_req_dn.bv_val, op->orr_newrdn.bv_val, 0);
 
 	if ( !dnIsSuffix( &op->o_req_ndn, &ud->dn ) && 
-		(!op->orr_nnewSup || !dnIsSuffix( &op->orr_nnewSup, &ud->dn )))
+		(!op->orr_nnewSup || !dnIsSuffix( op->orr_nnewSup, &ud->dn )))
 		return SLAP_CB_CONTINUE;
 
 	if(ldap_bv2rdn_x(&op->oq_modrdn.rs_newrdn, &newrdn,
