@@ -1,5 +1,5 @@
 /* repl.c - log modifications for replication purposes */
-/* $OpenLDAP: pkg/ldap/servers/slapd/repl.c,v 1.49.2.7 2005/01/20 17:01:09 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/repl.c,v 1.65.2.4 2005/08/09 21:03:59 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2005 The OpenLDAP Foundation.
@@ -41,14 +41,14 @@
 
 int
 add_replica_info(
-    Backend     *be,
-    const char  *host 
-)
+	Backend		*be,
+	const char	*uri, 
+	const char	*host )
 {
 	int i = 0;
 
-	assert( be );
-	assert( host );
+	assert( be != NULL );
+	assert( host != NULL );
 
 	if ( be->be_replica != NULL ) {
 		for ( ; be->be_replica[ i ] != NULL; i++ );
@@ -59,7 +59,8 @@ add_replica_info(
 
 	be->be_replica[ i ] 
 		= ch_calloc( sizeof( struct slap_replica_info ), 1 );
-	be->be_replica[ i ]->ri_host = ch_strdup( host );
+	be->be_replica[ i ]->ri_uri = uri;
+	be->be_replica[ i ]->ri_host = host;
 	be->be_replica[ i ]->ri_nsuffix = NULL;
 	be->be_replica[ i ]->ri_attrs = NULL;
 	be->be_replica[ i + 1 ] = NULL;
@@ -67,6 +68,45 @@ add_replica_info(
 	return( i );
 }
 
+int
+destroy_replica_info(
+	Backend		*be )
+{
+	int i = 0;
+
+	assert( be != NULL );
+
+	if ( be->be_replica == NULL ) {
+		return 0;
+	}
+
+	for ( ; be->be_replica[ i ] != NULL; i++ ) {
+
+		ch_free( (char *)be->be_replica[ i ]->ri_uri );
+
+		ber_bvarray_free( be->be_replica[ i ]->ri_nsuffix );
+
+		if ( be->be_replica[ i ]->ri_attrs ) {
+			AttributeName	*an = be->be_replica[ i ]->ri_attrs;
+			int		j;
+
+			for ( j = 0; !BER_BVISNULL( &an[ j ].an_name ); j++ )
+			{
+				ch_free( an[ j ].an_name.bv_val );
+			}
+			ch_free( an );
+		}
+
+		bindconf_free( &be->be_replica[ i ]->ri_bindconf );
+
+		ch_free( be->be_replica[ i ] );
+	}
+
+	ch_free( be->be_replica );
+
+	return 0;
+}
+
 int
 add_replica_suffix(
     Backend     *be,
@@ -124,8 +164,6 @@ replog1( struct slap_replica_info *ri, Operation *op, FILE *fp, long now);
 void
 replog( Operation *op )
 {
-	Modifications	*ml = NULL;
-	Attribute	*a = NULL;
 	FILE	*fp, *lfp;
 	int	i;
 /* undef NO_LOG_WHEN_NO_REPLICAS */
@@ -133,15 +171,17 @@ replog( Operation *op )
 	int     count = 0;
 #endif
 	int	subsets = 0;
-	long now = slap_get_time();
+	long	now = slap_get_time();
+	char	*replogfile;
 
-	if ( op->o_bd->be_replogfile == NULL && replogfile == NULL ) {
+	replogfile = op->o_bd->be_replogfile ? op->o_bd->be_replogfile :
+		frontendDB->be_replogfile;
+	if ( !replogfile ) {
 		return;
 	}
 
 	ldap_pvt_thread_mutex_lock( &replog_mutex );
-	if ( (fp = lock_fopen( op->o_bd->be_replogfile ? op->o_bd->be_replogfile :
-	    replogfile, "a", &lfp )) == NULL ) {
+	if ( (fp = lock_fopen( replogfile, "a", &lfp )) == NULL ) {
 		ldap_pvt_thread_mutex_unlock( &replog_mutex );
 		return;
 	}
@@ -274,7 +314,7 @@ replog1(
 
 	case LDAP_REQ_MODIFY:
 		for ( ml = op->orm_modlist; ml != NULL; ml = ml->sml_next ) {
-			char *did, *type = ml->sml_desc->ad_cname.bv_val;
+			char *did = NULL, *type = ml->sml_desc->ad_cname.bv_val;
 			switch ( ml->sml_op ) {
 			case LDAP_MOD_ADD:
 				did = "add"; break;
