@@ -1,5 +1,5 @@
 /* schema_init.c - init builtin schema */
-/* $OpenLDAP: pkg/ldap/servers/slapd/schema_init.c,v 1.360.2.8 2005/08/25 05:01:18 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/schema_init.c,v 1.360.2.9 2005/09/28 00:30:31 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2005 The OpenLDAP Foundation.
@@ -1066,7 +1066,7 @@ uniqueMemberMatch(
 	struct berval *asserted = (struct berval *) assertedValue;
 	struct berval assertedDN = *asserted;
 	struct berval assertedUID = BER_BVNULL;
-	struct berval valueDN = BER_BVNULL;
+	struct berval valueDN = *value;
 	struct berval valueUID = BER_BVNULL;
 	int approx = ((flags & SLAP_MR_EQUALITY_APPROX) == SLAP_MR_EQUALITY_APPROX);
 
@@ -1087,7 +1087,6 @@ uniqueMemberMatch(
 	}
 
 	if ( !BER_BVISEMPTY( value ) ) {
-		valueDN = *value;
 
 		valueUID.bv_val = strrchr( valueDN.bv_val, '#' );
 		if ( !BER_BVISNULL( &valueUID ) ) {
@@ -3430,8 +3429,8 @@ static slap_syntax_defs_rec syntax_defs[] = {
 		SLAP_SYNTAX_HIDE, NULL, NULL},
 #endif
 
-	{"( 1.3.6.1.4.1.4203.666.2.6 DESC 'UUID' )",
-		SLAP_SYNTAX_HIDE, UUIDValidate, NULL},
+	{"( 1.3.6.1.1.16.1 DESC 'UUID' )",
+		0, UUIDValidate, NULL},
 
 	{"( 1.3.6.1.4.1.4203.666.11.2.1 DESC 'CSN' )",
 		SLAP_SYNTAX_HIDE, csnValidate, NULL},
@@ -3854,16 +3853,16 @@ static slap_mrule_defs_rec mrule_defs[] = {
 		NULL, NULL,
 		"integerMatch" },
 
-	{"( 1.3.6.1.4.1.4203.666.4.6 NAME 'UUIDMatch' "
-		"SYNTAX 1.3.6.1.4.1.4203.666.2.6 )",
-		SLAP_MR_HIDE | SLAP_MR_EQUALITY, NULL,
+	{"( 1.3.6.1.1.16.2 NAME 'UUIDMatch' "
+		"SYNTAX 1.3.6.1.1.16.1 )",
+		SLAP_MR_EQUALITY, NULL,
 		NULL, UUIDNormalize, octetStringMatch,
 		octetStringIndexer, octetStringFilter,
 		NULL},
 
-	{"( 1.3.6.1.4.1.4203.666.4.7 NAME 'UUIDOrderingMatch' "
-		"SYNTAX 1.3.6.1.4.1.4203.666.2.6 )",
-		SLAP_MR_HIDE | SLAP_MR_ORDERING, NULL,
+	{"( 1.3.6.1.1.16.3 NAME 'UUIDOrderingMatch' "
+		"SYNTAX 1.3.6.1.1.16.1 )",
+		SLAP_MR_ORDERING, NULL,
 		NULL, UUIDNormalize, octetStringOrderingMatch,
 		octetStringIndexer, octetStringFilter,
 		"UUIDMatch"},
