@@ -1,5 +1,5 @@
 /* slapi_overlay.c - SLAPI overlay */
-/* $OpenLDAP: pkg/ldap/servers/slapd/slapi/slapi_overlay.c,v 1.34.2.1 2005/08/09 21:04:10 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/slapi/slapi_overlay.c,v 1.34.2.2 2005/08/19 18:09:06 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2001-2005 The OpenLDAP Foundation.
@@ -190,7 +190,7 @@ slapi_over_call_plugins( Slapi_PBlock *pb, int type )
 	PBLOCK_ASSERT_OP( pb, 0 );
 	op = pb->pb_op;
 
-	if ( op->o_bd != frontendDB ) {
+	if ( !be_match( op->o_bd, frontendDB ) ) {
 		rc = slapi_int_call_plugins( frontendDB, type, pb );
 	}
 	if ( rc >= 0 ) {
