@@ -1,5 +1,5 @@
 /* syncrepl.c -- Replication Engine which uses the LDAP Sync protocol */
-/* $OpenLDAP: pkg/ldap/servers/slapd/syncrepl.c,v 1.168.2.14 2005/10/07 16:53:34 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/syncrepl.c,v 1.168.2.16 2005/10/12 21:33:52 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 2003-2005 The OpenLDAP Foundation.
@@ -31,10 +31,6 @@
 
 #include "ldap_rq.h"
 
-/* FIXME: for ldap_ld_free() */
-#undef ldap_debug
-#include "../../libraries/libldap/ldap-int.h"
-
 struct nonpresent_entry {
 	struct berval *npe_name;
 	struct berval *npe_nname;
@@ -906,7 +902,7 @@ do_syncrepl(
 	struct re_s* rtask = arg;
 	syncinfo_t *si = ( syncinfo_t * ) rtask->arg;
 	Connection conn = {0};
-	char opbuf[OPERATION_BUFFER_SIZE];
+	OperationBuffer opbuf;
 	Operation *op;
 	int rc = LDAP_SUCCESS;
 	int first = 0;
@@ -942,7 +938,7 @@ do_syncrepl(
 		return NULL;
 	}
 
-	op = (Operation *)opbuf;
+	op = (Operation *) &opbuf;
 	connection_fake_init( &conn, op, ctx );
 
 	/* use global malloc for now */
@@ -2497,7 +2493,7 @@ syncinfo_free( syncinfo_t *sie )
 	    avl_free( sie->si_presentlist, avl_ber_bvfree );
 	}
 	if ( sie->si_ld ) {
-		ldap_ld_free( sie->si_ld, 1, NULL, NULL );
+		ldap_unbind_ext( sie->si_ld, NULL, NULL );
 	}
 	while ( !LDAP_LIST_EMPTY( &sie->si_nonpresentlist )) {
 		struct nonpresent_entry* npe;
