@@ -1,5 +1,5 @@
 /* value.c - routines for dealing with values */
-/* $OpenLDAP: pkg/ldap/servers/slapd/value.c,v 1.79.2.4 2005/08/12 15:25:20 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/value.c,v 1.79.2.6 2005/08/29 18:26:10 kurt Exp $ */
 /* This work is part of OpenLDAP Software <http://www.openldap.org/>.
  *
  * Copyright 1998-2005 The OpenLDAP Foundation.
@@ -322,7 +322,7 @@ ordered_value_sort( Attribute *a, int do_renumber )
 			char *ptr;
 			index = 1;
 			ptr = strchr( a->a_vals[i].bv_val, '}' );
-			if ( !ptr || !ptr[1] )
+			if ( !ptr )
 				return LDAP_INVALID_SYNTAX;
 			if ( noindex )
 				return LDAP_INVALID_SYNTAX;
@@ -361,8 +361,14 @@ ordered_value_sort( Attribute *a, int do_renumber )
 #endif
 				
 		indexes = ch_malloc( vals * sizeof(int) );
-		for ( i=0; i<vals; i++)
-			indexes[i] = strtol(a->a_vals[i].bv_val+1, NULL, 0);
+		for ( i=0; i<vals; i++) {
+			char *ptr;
+			indexes[i] = strtol(a->a_vals[i].bv_val+1, &ptr, 0);
+			if ( *ptr != '}' ) {
+				ch_free( indexes );
+				return LDAP_INVALID_SYNTAX;
+			}
+		}
 
 		/* Insertion sort */
 		for ( i=1; i<vals; i++ ) {
